@@ -1,6 +1,6 @@
 /*
 
-  $Id: cfgreader.c,v 1.58 2005/04/20 22:33:36 pkot Exp $
+  $Id: cfgreader.c,v 1.62 2005/07/24 18:58:13 pkot Exp $
 
   G N O K I I
 
@@ -36,9 +36,6 @@
 
 */
 
-
-/* for strndup */
-#define _GNU_SOURCE
 #include "config.h"
 #include "compat.h"
 #include "misc.h"
@@ -230,6 +227,7 @@ struct gn_cfg_header *cfg_file_read(const char *filename)
 	line_begin = lines;
 	num_lines = 0;
 	copied = 0;
+
 	while ((pos = strchr(line_begin, '\n')) && copied < read) {
 		char *buf;
 
@@ -240,7 +238,9 @@ struct gn_cfg_header *cfg_file_read(const char *filename)
 		}
 
 		num_lines++;
-		buf = (char *)strndup(line_begin, line_end - line_begin);
+		buf = malloc(line_end - line_begin + 1);
+		strncpy(buf, line_begin, line_end - line_begin);
+		buf[line_end - line_begin] = 0;
 		split_lines = realloc(split_lines,
 				(num_lines + 1) * sizeof(char*));
 		split_lines[num_lines - 1] = buf;
@@ -554,7 +554,7 @@ API int gn_cfg_read(char **bindir)
 
 	retval = gn_cfg_read_default();
 
-	(char *)*bindir = gn_cfg_get(gn_cfg_info, "global", "bindir");
+	*bindir = gn_cfg_get(gn_cfg_info, "global", "bindir");
 	if (!*bindir)
 		*bindir = gn_cfg_get(gn_cfg_info, "gnokiid", "bindir");
 	if (!*bindir)
@@ -638,13 +638,13 @@ API int gn_cfg_memory_read(const char **lines)
 	return cfg_file_or_memory_read(NULL, lines);
 }
 
-API bool gn_cfg_phone_load(const char *iname, struct gn_statemachine *state)
+API int gn_cfg_phone_load(const char *iname, struct gn_statemachine *state)
 {
 	char section[256];
 
-	if (iname == NULL || *iname == '\0')
+	if (iname == NULL || *iname == '\0') {
 		state->config = gn_config_global;
-	else {
+	} else {
 		snprintf(section, sizeof(section), "phone_%s", iname);
 		if (!cfg_psection_load(&state->config, section, &gn_config_global))
 			return false;
