@@ -1,6 +1,6 @@
 /*
  *
- * $Id: winirda.c,v 1.12 2005/04/20 20:37:41 pkot Exp $
+ * $Id: winirda.c,v 1.16 2005/07/18 20:55:36 bozo Exp $
  *
  * G N O K I I
  *
@@ -47,9 +47,13 @@ static char *phone[] = {
 	"Nokia 3360",
 	"Nokia 3650",
 	"Nokia 5100",
+	"Nokia 5140",
+	"Nokia 6020",
 	"Nokia 6100",
+	"Nokia 6170",
 	"Nokia 6210",
 	"Nokia 6230",
+	"Nokia 6230i",
 	"Nokia 6250",
 	"Nokia 6310",
 	"Nokia 6310i",
