@@ -1,6 +1,6 @@
 /*
 
-  $Id: gsm-filetypes.c,v 1.60 2005/04/20 22:33:36 pkot Exp $
+  $Id: gsm-filetypes.c,v 1.64 2005/06/29 21:19:30 pkot Exp $
 
   G N O K I I
 
@@ -1384,9 +1384,9 @@ gn_error gn_file_bitmap_show(char *filename)
 
 	for (i = 0; i < bitmap.height; i++) {
 		for (j = 0; j < bitmap.width; j++) {
-			printf("%c", gn_bmp_point(&bitmap, j, i) ? '#' : ' ');
+			fprintf(stdout, "%c", gn_bmp_point(&bitmap, j, i) ? '#' : ' ');
 		}
-		printf("\n");
+		fprintf(stdout, "\n");
 	}
 
 	return GN_ERR_NONE;
@@ -1402,15 +1402,12 @@ static int get_next_token(char *src, int delim)
 		switch (src[i]) {
 		case '\\':
 			if (slash_state) {
-				printf("enter\n");
 				slash_state = 0;
 			} else {
-				printf("exit\n");
 				slash_state = 1;
 			}
 			break;
 		case ';':
-			printf("semicolon\n");
 			if (slash_state)
 				slash_state = 0;
 			else
@@ -1422,7 +1419,7 @@ static int get_next_token(char *src, int delim)
 			break;
 		}
 	}
-	return i;
+	return i + 1;
 }
 
 #define BUG(x) \
@@ -1452,11 +1449,9 @@ API gn_error gn_file_phonebook_raw_parse(gn_phonebook_entry *entry, char *line)
 	entry->empty = true;
 	memory_type_char[2] = 0;
 
-	printf("%s\n", line + offset);
 	GET_NEXT_TOKEN();
 	switch (o) {
 	case 0:
-		dprintf("dupa1\n");
 		return GN_ERR_WRONGDATAFORMAT;
 	case 1:
 		/* empty name: this is a request to delete the entry */
@@ -1469,11 +1464,9 @@ API gn_error gn_file_phonebook_raw_parse(gn_phonebook_entry *entry, char *line)
 
 	BUG(offset >= length);
 
-	printf("%s\n", line + offset);
 	GET_NEXT_TOKEN();
 	switch (o) {
 	case 0:
-		dprintf("dupa2\n");
 		return GN_ERR_WRONGDATAFORMAT;
 	default:
 		break;
@@ -1483,13 +1476,11 @@ API gn_error gn_file_phonebook_raw_parse(gn_phonebook_entry *entry, char *line)
 
 	BUG(offset >= length);
 
-	printf("%s\n", line + offset);
 	GET_NEXT_TOKEN();
 	switch (o) {
 	case 3:
 		break;
 	default:
-		dprintf("dupa3: %d\n", o);
 		return GN_ERR_WRONGDATAFORMAT;
 	}
 	STORE_TOKEN(memory_type_char);
@@ -1512,7 +1503,6 @@ API gn_error gn_file_phonebook_raw_parse(gn_phonebook_entry *entry, char *line)
 	STORE_TOKEN(number);
 	switch (o) {
 	case 0:
-		dprintf("dupa4\n");
 		return GN_ERR_WRONGDATAFORMAT;
 	case 1:
 		entry->location = 0;
@@ -1530,7 +1520,6 @@ API gn_error gn_file_phonebook_raw_parse(gn_phonebook_entry *entry, char *line)
 	STORE_TOKEN(number);
 	switch (o) {
 	case 0:
-		dprintf("dupa5\n");
 		return GN_ERR_WRONGDATAFORMAT;
 	case 1:
 		entry->caller_group = 0;
