@@ -1,6 +1,6 @@
 /*
 
-  $Id: misc.c,v 1.92 2005/04/20 22:33:36 pkot Exp $
+  $Id: misc.c,v 1.97 2005/07/18 20:55:36 bozo Exp $
 
   G N O K I I
 
@@ -182,6 +182,7 @@ static gn_phone_model models[] = {
 	{"5120",  "NSC-1", PM_KEYBOARD  },
 	{"5125",  "NSC-1", PM_KEYBOARD },
 	{"5130",  "NSK-1", PM_NETMONITOR | PM_KEYBOARD | PM_SMS | PM_DTMF | PM_DATA | PM_SPEEDDIAL | PM_AUTHENTICATION },
+	{"5140",  "NPL-5", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"5160",  "NSW-1", PM_NETMONITOR | PM_KEYBOARD | PM_SMS | PM_DTMF | PM_DATA | PM_SPEEDDIAL | PM_AUTHENTICATION },
 	{"5170",  "NSD-1F", 0 },
 	{"5180",  "NSD-1G", 0 },
@@ -192,6 +193,8 @@ static gn_phone_model models[] = {
 	{"6010",  "NPM-10", 0 },
 	{"6010",  "NPM-10X", 0 },
 	{"6011",  "RTE-2RH", 0 },
+	{"6020",  "RM-30", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_NETMONITOR | PM_EXTPBK | PM_SMS | PM_FOLDERS },
+	{"6021",  "RM-94", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_NETMONITOR | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"6050",  "NME-1", 0 },
 	{"6080",  "NME-2", 0 },
 	{"6081",  "NME-2A", 0 },
@@ -217,6 +220,8 @@ static gn_phone_model models[] = {
 	{"6220",  "RH-20", 0 },
 	{"6225",  "RH-27", 0 },
 	{"6230",  "RH-12_28_-", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_NETMONITOR | PM_EXTPBK | PM_SMS | PM_FOLDERS },
+	{"6230",  "RH12_28_-", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_NETMONITOR | PM_EXTPBK | PM_SMS | PM_FOLDERS },
+	{"6230i", "RM72_73_-", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_NETMONITOR | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"6250",  "NHM-3", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_NETMONITOR | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"6310",  "NPE-4", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_EXTPBK | PM_SMS | PM_FOLDERS | PM_KEYBOARD | PM_DTMF },
 	{"6310i", "NPL-1", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_EXTPBK | PM_SMS | PM_FOLDERS | PM_KEYBOARD | PM_DTMF },
