@@ -1,6 +1,6 @@
 /*
 
-  $Id: vcal.c,v 1.4 2005/04/20 22:33:36 pkot Exp $
+  $Id: vcal.c,v 1.6 2005/05/19 22:02:48 pkot Exp $
 
   G N O K I I
 
@@ -270,7 +270,7 @@ API int gn_ical2calnote(FILE *f, gn_calnote *calnote, int id)
 	iterate_cal(comp, 0, &id, &compresult, ICAL_VEVENT_COMPONENT);
 
 	if (!compresult) {
-		fprintf(stderr, _("No component found."));
+		fprintf(stderr, _("No component found.\n"));
 	} else {
 		const char *str;
 		icalcomponent *alarm = {0};
@@ -350,9 +350,12 @@ API int gn_ical2calnote(FILE *f, gn_calnote *calnote, int id)
 		fprintf(stderr, _("Component found\n%s\n"), icalcomponent_as_ical_string(compresult));
 
 	}
-	icalcomponent_free(compresult);
-	icalcomponent_free(comp);
-	icalparser_free(parser);
+	if (compresult)
+		icalcomponent_free(compresult);
+	if (comp)
+		icalcomponent_free(comp);
+	if (parser)
+		icalparser_free(parser);
 #else
 	retval = GN_ERR_NOTIMPLEMENTED;
 #endif /* HAVE_LIBICAL */
@@ -377,7 +380,7 @@ API int gn_todo2ical(FILE *f, gn_todo *ctodo)
 							0),
 				    0);
 
-	if(pIcal) {
+	if (pIcal) {
 		char *icalstrbuf = NULL;
 		const char *icalstr = icalcomponent_as_ical_string(pIcal);
 		/* conversion to UTF-8 */
@@ -436,7 +439,7 @@ API int gn_ical2todo(FILE *f, gn_todo *ctodo, int id)
 	iterate_cal(comp, 0, &id, &compresult, ICAL_VTODO_COMPONENT);
 
 	if (!compresult) {
-		fprintf(stderr, _("No component found."));
+		fprintf(stderr, _("No component found.\n"));
 	} else {
 		const char *priostr = NULL;
 		icalproperty *priority = icalcomponent_get_first_property(compresult, ICAL_PRIORITY_PROPERTY);
