@@ -1,10 +1,10 @@
 /*
 
-  $Id: gnokii-app.h,v 1.37 2003/10/23 00:35:02 bozo Exp $
+  $Id: gnokii-app.h,v 1.38 2005/04/20 20:18:51 pkot Exp $
 
   G N O K I I
 
-  A Linux/Unix toolset and driver for Nokia mobile phones.
+  A Linux/Unix toolset and driver for the mobile phones.
 
   This file is part of gnokii.
 
@@ -22,9 +22,12 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 1999, 2000 Hugh Blemings & Pavel Jank ml.
-
-  Header file for test utility.
+  Copyright (C) 1999-2000  Hugh Blemings & Pavel Jank ml.
+  Copyright (C) 2000-2001  Pawel Kot
+  Copyright (C) 2001       Jan Kratochvil
+  Copyright (C) 2003       BORBELY Zoltan
+  
+  Header file for gnokii utility.
 
 */
 
