@@ -1,10 +1,10 @@
 /*
 
-  $Id: nk6510.h,v 1.22 2004/02/18 21:49:43 uid66843 Exp $
+  $Id: nk6510.h,v 1.24 2005/04/24 20:05:19 pkot Exp $
 
   G N O K I I
 
-  A Linux/Unix toolset and driver for Nokia mobile phones.
+  A Linux/Unix toolset and driver for the mobile phones.
 
   This file is part of gnokii.
 
@@ -22,7 +22,9 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 2002 Markus Plail
+  Copyright (C) 2000      Hugh Blemings, Pavel Janik
+  Copyright (C) 2001-2004 BORBELY Zoltan, Pawel Kot
+  Copyright (C) 2002      Markus Plail
 
   This file provides functions specific to the 6510 series.
   See README for more details on supported mobile phones.
@@ -56,6 +58,7 @@ typedef enum {
 #define NK6510_MSG_SUBSCRIBE	0x10	/* subscribe to channels */
 #define NK6510_MSG_CALENDAR	0x13	/* Calendar notes */
 #define NK6510_MSG_FOLDER	0x14	/* Folders handling */
+#define NK6510_MSG_RESET        0x15	/* Reset */
 #define NK6510_MSG_BATTERY	0x17	/* Battery info */
 #define NK6510_MSG_CLOCK	0x19	/* Date & alarm */
 #define NK6510_MSG_IDENTITY	0x1b	/* Brief product info */
@@ -63,8 +66,9 @@ typedef enum {
 #define NK6510_MSG_PROFILE	0x39	/* Profiles */
 #define NK6510_MSG_NOTKNOWN	0x3E	/*          */
 #define NK6510_MSG_WAP		0x3F	/* WAP */
-#define NK6510_MSG_RADIO    	0x43	/* Radio (6510/8310) */
+#define NK6510_MSG_RADIO    	0x43	/* Radio (6510/8310) + hard reset */
 #define NK6510_MSG_TODO    	0x55	/* ToDo */
+#define NK6510_MSG_FILE	        0x6d	/* File Handling */
 #define NK6510_MSG_STLOGO	0x7a	/* Startup logo */
 
 /* SMS handling message subtypes (send) */
