@@ -1,10 +1,10 @@
 /*
 
-  $Id: nk7110.h,v 1.27 2004/02/18 21:49:43 uid66843 Exp $
+  $Id: nk7110.h,v 1.29 2005/04/24 20:05:19 pkot Exp $
 
   G N O K I I
 
-  A Linux/Unix toolset and driver for Nokia mobile phones.
+  A Linux/Unix toolset and driver for the mobile phones.
 
   This file is part of gnokii.
 
@@ -22,8 +22,10 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 2000 Hugh Blemings & Pavel Jank ml.
-  Copyright (C) 2000 Chris Kemp
+  Copyright (C) 2000      Hugh Blemings & Pavel Jank ml.
+  Copyright (C) 2000      Chris Kemp
+  Copyright (C) 2001-2003 Pawel Kot, BORBELY Zoltan
+  Copyright (C) 2002      Markus Plail
 
   This file provides functions specific to the 7110 series.
   See README for more details on supported mobile phones.
@@ -90,10 +92,14 @@ typedef enum {
 #define NK7110_SUBSMS_PICTURE_LIST_OK	0x97	/* Picture messages list received */
 
 /* Clock handling message subtypes (send) */
+#define NK7110_SUBCLO_SET_DATE		0x60	/* Set date & time */
 #define NK7110_SUBCLO_GET_DATE		0x62	/* Get date & time */
+#define NK7110_SUBCLO_SET_ALARM		0x6B	/* Set alarm */
 #define NK7110_SUBCLO_GET_ALARM		0x6D	/* Get alarm */
 /* Clock handling message subtypes (recv) */
+#define NK7110_SUBCLO_DATE_SET		0x61	/* Date & time set */
 #define NK7110_SUBCLO_DATE_RCVD		0x63	/* Received date & time */
+#define NK7110_SUBCLO_ALARM_SET		0x6C	/* Alarm set */
 #define NK7110_SUBCLO_ALARM_RCVD	0x6E	/* Received alarm */
 /* Alarm on/off */
 #define NK7110_ALARM_ENABLED		0x02	/* Alarm enabled */
