@@ -1,10 +1,10 @@
 /*
 
-  $Id: lowlevel.c,v 1.35 2004/02/20 11:02:26 uid66849 Exp $
+  $Id: lowlevel.c,v 1.40 2005/04/26 06:34:39 ja Exp $
 
   S M S D
 
-  A Linux/Unix GUI for Nokia mobile phones.
+  A Linux/Unix tool for the mobile phones.
 
   This file is part of gnokii.
 
@@ -22,8 +22,8 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 1999 Pavel Jank ml., Hugh Blemings
-  & Jn Derfik <ja@mail.upjs.sk>.
+  Copyright (C) 1999      Pavel Jank ml., Hugh Blemings
+  Copyright (C) 1999-2004 Jan Derfinak
 
 */
 
@@ -128,14 +128,6 @@ static gn_error fbusinit (const char * const iname)
   char *aux;
   static bool atexit_registered = false;
   
-  /* register cleanup function */
-  if (!atexit_registered)
-  {
-    atexit_registered = true;
-    atexit (busterminate);
-  }
-  /* signal(SIGINT, bussignal); */
-
   if (!gn_cfg_phone_load (iname, &sm))
   {
     g_print (_("Cannot load phone %s!\nDo you have proper section in gnokiirc?\n"), iname);
@@ -154,6 +146,14 @@ static gn_error fbusinit (const char * const iname)
     }
   }
 
+  /* register cleanup function */
+  if (!atexit_registered)
+  {
+    atexit_registered = true;
+    atexit (busterminate);
+  }
+  /* signal(SIGINT, bussignal); */
+
   /* Initialise the code for the GSM interface. */     
 
   error = gn_gsm_initialise (&sm);
@@ -237,10 +237,7 @@ static void RefreshSMS (const gint number)
   {
     msg = g_malloc (sizeof (gn_sms));
     memset (msg, 0, sizeof (gn_sms));
-    if (phoneMonitor.supported & PM_FOLDERS)
-      msg->memory_type = GN_MT_IN;
-    else
-      msg->memory_type = GN_MT_SM;
+    msg->memory_type = smsdConfig.memoryType;
     msg->number = ++i;
     data.sms = msg;
     
@@ -354,6 +351,7 @@ gint (*DoAction[])(gpointer) = {
 
 void *Connect (void *phone)
 {
+  static gint status = 1;
   gn_data *data;
   gn_sms_status SMSStatus = {0, 0, 0, 0};
   gn_sms_folder SMSFolder;
@@ -370,6 +368,13 @@ void *Connect (void *phone)
     exit (1);
   }
 
+  if (smsdConfig.memoryType == GN_MT_XX) {
+    if (phoneMonitor.supported & PM_FOLDERS)
+      smsdConfig.memoryType = GN_MT_IN;
+    else
+      smsdConfig.memoryType = GN_MT_SM;
+  }
+
   gn_log_xdebug ("Phone connected. Starting monitoring...\n");
 
   while (1)
@@ -379,8 +384,8 @@ void *Connect (void *phone)
     if (phoneMonitor.supported & PM_FOLDERS)
     {
       data->sms_folder = &SMSFolder;
-      SMSFolder.folder_id = GN_MT_IN;
-      if ((error = gn_sm_functions (GN_OP_GetSMSFolderStatus, data, &sm)) == GN_ERR_NONE)
+      SMSFolder.folder_id = smsdConfig.memoryType;
+      if (status && (error = gn_sm_functions (GN_OP_GetSMSFolderStatus, data, &sm)) == GN_ERR_NONE)
       {
         if (phoneMonitor.sms.number != SMSFolder.number)
         {
@@ -391,12 +396,25 @@ void *Connect (void *phone)
         phoneMonitor.sms.unRead = 0;
       }
       else
-        g_print (_("GN_OP_GetSMSFolderStatus at line %d in file %s returns error %d\n"), __LINE__, __FILE__, error);
+      {
+        if (status)
+        {
+          g_print (_("GN_OP_GetSMSFolderStatus at line %d in file %s returns error %d\nEntering dumb mode."), __LINE__, __FILE__, error);
+          status = 0;
+        }
+        phoneMonitor.working = TRUE;
+        RefreshSMS (smsdConfig.maxSMS);
+        phoneMonitor.working = FALSE;
+      }
     }
     else
     {
+      gn_memory_status dummy;
+      dummy.memory_type = smsdConfig.memoryType;
+
       data->sms_status = &SMSStatus;
-      if ((error = gn_sm_functions (GN_OP_GetSMSStatus, data, &sm)) == GN_ERR_NONE)
+      data->memory_status = &dummy;
+      if (status && (error = gn_sm_functions (GN_OP_GetSMSStatus, data, &sm)) == GN_ERR_NONE)
       {
         if (phoneMonitor.sms.unRead != SMSStatus.unread ||
             phoneMonitor.sms.number != SMSStatus.number)
@@ -408,7 +426,16 @@ void *Connect (void *phone)
         phoneMonitor.sms.unRead = SMSStatus.unread;
       }
       else
-        g_print (_("GN_OP_GetSMSStatus at line %d in file %s returns error %d\n"), __LINE__, __FILE__, error);
+      {
+        if (status)
+        {
+          g_print (_("GN_OP_GetSMSStatus at line %d in file %s returns error %d\nEntering dumb mode."), __LINE__, __FILE__, error);
+          status = 0;
+        }
+        phoneMonitor.working = TRUE;
+        RefreshSMS (smsdConfig.maxSMS);
+        phoneMonitor.working = FALSE;
+      }
     }
 
     while ((event = RemoveEvent ()) != NULL)
@@ -421,7 +448,7 @@ void *Connect (void *phone)
       g_free (event);
     }
     
-    sleep (1);
+    sleep (smsdConfig.refreshInt);
   }
   
   free (data);
