@@ -1,10 +1,10 @@
 /*
 
-  $Id: smsd.h,v 1.11 2003/10/05 19:42:41 ja Exp $
+  $Id: smsd.h,v 1.15 2005/04/26 06:34:39 ja Exp $
 
   S M S D
 
-  A Linux/Unix GUI for Nokia mobile phones.
+  A Linux/Unix tool for the mobile phones.
 
   This file is part of gnokii.
 
@@ -23,7 +23,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
   Copyright (C) 1999 Pavel Jank ml., Hugh Blemings
-  & Jn Derfik <ja@mail.upjs.sk>.
+  Copyright (C) 1999-2005 Jan Derfinak
 
 */
 
@@ -43,7 +43,10 @@ typedef struct {
   gchar *libDir;
   gchar *logFile;
   gchar *phone;
+  gint   refreshInt;
+  gint   maxSMS;
   gint   smsSets:4;
+  gn_memory_type memoryType;
 } SmsdConfig;
 
 typedef struct {
