@@ -1,6 +1,6 @@
 /*
 
-  $Id: xgnokii_lowlevel.c,v 1.88 2005/04/24 20:57:37 pkot Exp $
+  $Id: xgnokii_lowlevel.c,v 1.89 2005/06/09 20:38:24 pkot Exp $
   
   X G N O K I I
 
@@ -425,11 +425,18 @@ static void RefreshSMS(const gint number)
 					g_free(fld);
 					break;
 				}
-			} else if (error == GN_ERR_INVALIDLOCATION) {	/* All positions are read */
+			} else if (error == GN_ERR_INVALIDLOCATION) {
+				/* All positions are read */
 				g_free(list);
 				g_free(fld);
 				g_free(msg);
 				break;
+			} else if (error == GN_ERR_INVALIDMEMORYTYPE) {
+				/* We have some misconfiguration: phone doesn't handle
+				   neither folders nor SIM */
+				fprintf(stderr, _("Misconfiguration detected: phone handles neither folders nor sim.\n"
+						  "Contact gnokii developers to fix the issue.\n"));
+				break;
 			} else {
 				g_free(msg);
 				usleep(750000);
